"use client";

import { useEffect } from "react";
import Link from "next/link";
import { useRouter, useSearchParams } from "next/navigation";
import { MessageCircleCode } from "lucide-react";

import { UserAuthForm } from "@/components/auth/user-auth-form";

export default function AuthPage() {
  const router = useRouter();
  const searchParams = useSearchParams();

  useEffect(() => {
    // 如果有 OAuth 参数，重定向回 /oauth/authorize
    if (searchParams.has("response_type") && searchParams.has("client_id")) {
      console.log("检测到 OAuth 参数，准备重定向到 /oauth/authorize");
      router.replace(`/oauth/authorize?${searchParams.toString()}`);
      return;
    }
  }, [router, searchParams]);

  return (
    <div className="mx-auto flex w-full flex-col justify-center space-y-6 sm:w-[350px]">
      <div className="flex flex-col space-y-2 text-center">
        <MessageCircleCode className="mx-auto size-12" />
        <div className="text-2xl font-semibold tracking-tight">
          <span>Welcome to</span>{" "}
          <span style={{ fontFamily: "Bahamas Bold" }}>Q58论坛</span>
        </div>
      </div>
      <UserAuthForm />
      <p className="px-8 text-center text-sm text-muted-foreground">
        By clicking continue, you agree to our{" "}
        <Link
          href="https://q58.club/tos"
          className="hover:text-brand underline underline-offset-4"
        >
          Terms of Service
        </Link>{" "}
        and{" "}
        <Link
          href="https://q58.club/privacy"
          className="hover:text-brand underline underline-offset-4"
        >
          Privacy Policy
        </Link>
        .
      </p>
    </div>
  );
}
