import { cookies } from "next/headers";
import Hex from "crypto-js/enc-hex";
import hmacSHA256 from "crypto-js/hmac-sha256";
import WordArray from "crypto-js/lib-typedarrays";

import { AUTH_NONCE } from "@/lib/constants";

const hostUrl = process.env.NEXT_PUBLIC_HOST_URL as string;
const discourseHost = process.env.DISCOURSE_HOST as string;
const clientSecret = process.env.DISCOURSE_SECRET as string;

export async function POST(req: Request) {
  console.log("开始处理 SSO 登录请求...");

  try {
    const nonce = WordArray.random(16).toString();
    let return_url = `${hostUrl}/authorize`;

    try {
      const body = await req.json();
      console.log("收到请求体:", body);

      if (body.return_url) {
        return_url = `${hostUrl}${body.return_url}`;
        console.log("使用自定义 return_url:", return_url);
      } else {
        console.log("使用默认 return_url:", return_url);
      }
    } catch (error) {
      console.error("解析请求体失败:", error);
    }

    console.log("生成 SSO 参数...");
    const sso = btoa(`nonce=${nonce}&return_sso_url=${return_url}`);
    const sig = hmacSHA256(sso, clientSecret).toString(Hex);

    console.log("设置 nonce cookie...");
    cookies().set(AUTH_NONCE, nonce, {
      maxAge: 60 * 10,
      path: "/",
      httpOnly: true,
      secure: process.env.NODE_ENV === "production",
    });

    const sso_url = `${discourseHost}/session/sso_provider?sso=${sso}&sig=${sig}`;
    console.log("生成 SSO URL:", sso_url);

    return Response.json({
      sso_url: sso_url,
    });
  } catch (error) {
    console.error("SSO 处理错误:", error);
    const errorMessage = error instanceof Error ? error.message : String(error);
    return Response.json(
      {
        error: "处理登录请求时发生错误",
        details: errorMessage,
      },
      { status: 500 },
    );
  }
}
