"use client";

import { useRouter } from "next/navigation";
import { AlertCircle } from "lucide-react";

import { Button } from "@/components/ui/button";
import {
  Card,
  CardContent,
  CardFooter,
  CardHeader,
  CardTitle,
} from "@/components/ui/card";

interface ErrorCardProps {
  title: string;
  description: string;
  redirectUri?: string;
  error?: string;
  errorDescription?: string;
}

export function ErrorCard({
  title,
  description,
  redirectUri,
  error,
  errorDescription,
}: ErrorCardProps) {
  const router = useRouter();

  const handleBack = () => {
    if (redirectUri) {
      const url = new URL(redirectUri);
      if (error) url.searchParams.set("error", error);
      if (errorDescription)
        url.searchParams.set("error_description", errorDescription);
      window.location.href = url.toString();
    } else {
      router.push("/");
    }
  };

  return (
    <Card className="w-full max-w-md">
      <CardHeader className="space-y-4 text-center">
        <div className="flex items-center justify-center">
          <div className="flex h-20 w-20 items-center justify-center rounded-full bg-red-50">
            <AlertCircle className="h-10 w-10 text-red-600" />
          </div>
        </div>
        <CardTitle className="text-2xl font-bold text-red-600">
          {title}
        </CardTitle>
      </CardHeader>
      <CardContent>
        <p className="text-center text-gray-500">{description}</p>
      </CardContent>
      <CardFooter className="flex justify-center">
        <Button
          variant="outline"
          className="min-w-[120px] border-red-200 text-red-600 hover:bg-red-50 hover:text-red-700"
          onClick={handleBack}
        >
          返回
        </Button>
      </CardFooter>
    </Card>
  );
}
